/* GTK - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*
 * Modified by the GTK+ Team and others 1997-2001.  See the AUTHORS
 * file for a list of people on the GTK+ Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
 */

#ifndef __G_ACCESSIBLE_ACTION_H__
#define __G_ACCESSIBLE_ACTION_H__

#include <gtk/a11y/gaccessible.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/*
 * Interface GaccessibleAction is implemented
 * using GObject interface registry and macros.
 */

#define TYPE_GACCESSIBLE_ACTION            (gaccessible_action_get_type ())
#define IS_GACCESSIBLE_ACTION(obj)         G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GACCESSIBLE_ACTION)
#define GACCESSIBLE_ACTION(obj)            G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GACCESSIBLE_ACTION, GaccessibleAction)
#define GACCESSIBLE_ACTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_GACCESSIBLE_ACTION, GaccessibleActionInterface))

#ifndef _TYPEDEF_GACCESSIBLE_ACTION_
#define _TYPEDEF_GACCESSIBLE_ACTION_
typedef struct _GaccessibleAction GaccessibleAction;
#endif

struct _GaccessibleActionInterface
{
  GTypeInterface parent;

  gboolean (*do_action)         (GaccessibleAction *action,
                                 gint              i);

  gint     (*get_count)         (GaccessibleAction *action);

  gchar*   (*get_description)   (GaccessibleAction *action,
                                 gint              i);
};
GType gaccessible_action_get_type ();

/*
 * These are the function which would be called by an application with
 * the argument being a Gaccessible object cast to (accessible_Action).
 *
 * This suggests that at least a wrapper implementation of the functions
 * needs to be in the GTK+ library. The function will just check that
 * the corresponding
 * function pointer is not NULL and will call it.
 *
 * The "real" implementation of the function for accessible will be
 * provided in our support library
 */

void   gaccessible_action_do_action        (GaccessibleAction *action,
                                            gint              i);
gint   gaccessible_action_get_action_count (GaccessibleAction *action);
gchar* gaccessible_action_get_description  (GaccessibleAction *action,
                                            gint              i);


/*
 * Additional GObject properties exported by GaccessibleAction:
 *    "accessible_action"
 *       (an accessible action, or the list of actions, has changed)
 */

#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __G_ACCESSIBLE_ACTION_H__ */









