/* GTK - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*
 * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
 * file for a list of people on the GTK+ Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
 */

#include <stdarg.h>
#include <string.h>

#include "gaccessiblecomponent.h"

GType
gaccessible_component_get_type ()
{
  static GType type = 0;

  if (!type) {
    GTypeInfo tinfo =
    {
      sizeof (GaccessibleComponentInterface),
      NULL,
      NULL,

    };

    type = g_type_register_static (G_TYPE_INTERFACE, "gaccessible_component", &tinfo, 0);
  }

  return type;
}

/**
 *
 **/
guint
gaccessible_component_add_focus_handler (GaccessibleComponent    *component,
                                         GaccessibleFocusHandler *listener)
{
  ;
}
/**
 *
 **/
void
gaccessible_component_remove_focus_handler (GaccessibleComponent    *component,
                                            guint                   handler_id)
{
  ;
}

gboolean
gaccessible_component_contains (GaccessibleComponent    *component,
                                gint                     x,
                                gint                     y)
{
  GaccessibleComponentInterface *iface = NULL;
  g_return_value_if_fail( (component != null), false);
  g_return_value_if_fail( G_IS_GACCESSIBLE_COMPONENT (component), false);
  g_return_value_if_fail( (iface = GACCESSIBLE_COMPONENT_GET_INTERFACE (component)), false );

  return ( *(iface->contains) (component, x, y));
}

Gaccessible*
gaccessible_component_get_accessible_at      (GaccessibleComponent    *component,
                                              gint                     x,
                                              gint                     y)
{
  GaccessibleComponentInterface *iface = NULL;
  g_return_value_if_fail( (component != null), false);
  g_return_value_if_fail( G_IS_GACCESSIBLE_COMPONENT (component), false);
  g_return_value_if_fail( (iface = GACCESSIBLE_COMPONENT_GET_INTERFACE (component)), false );

  return ( *(iface->get_accessible_at) (component, x, y));
}

void
gaccessible_component_get_bounds             (GaccessibleComponent    *component,
                                              gint                    *x,
                                              gint                    *y,
                                              gint                    *width,
                                              gint                    *length)
{
  GaccessibleComponentInterface *iface = NULL;
  g_return_value_if_fail( (component != null), false);
  g_return_value_if_fail( G_IS_GACCESSIBLE_COMPONENT (component), false);
  g_return_value_if_fail( (iface = GACCESSIBLE_COMPONENT_GET_INTERFACE (component)), false );

  return ( *(iface->get_accessible_at) (component, x, y));
}

GaccessibleCursorType
gaccessible_component_get_cursor_type        (GaccessibleComponent    *component)
{
  GaccessibleComponentInterface *iface = NULL;
  g_return_value_if_fail( (component != null), false);
  g_return_value_if_fail( G_IS_GACCESSIBLE_COMPONENT (component), false);
  g_return_value_if_fail( (iface = GACCESSIBLE_COMPONENT_GET_INTERFACE (component)), false );

  return ( *(iface->get_cursor_type) (component));
}

void
gaccessible_component_get_location           (GaccessibleComponent    *component,
                                              gint                    *x,
                                              gint                    *y)
{
  GaccessibleComponentInterface *iface = NULL;
  g_return_value_if_fail( (component != null), false);
  g_return_value_if_fail( G_IS_GACCESSIBLE_COMPONENT (component), false);
  g_return_value_if_fail( (iface = GACCESSIBLE_COMPONENT_GET_INTERFACE (component)), false );

  return ( *(iface->get_location) (component, x, y));
}

void
gaccessible_component_get_location_on_screen (GaccessibleComponent    *component,
                                              gint                    *x,
                                              gint                    *y)
{
  GaccessibleComponentInterface *iface = NULL;
  g_return_value_if_fail( (component != null), false);
  g_return_value_if_fail( G_IS_GACCESSIBLE_COMPONENT (component), false);
  g_return_value_if_fail( (iface = GACCESSIBLE_COMPONENT_GET_INTERFACE (component)), false );

  return ( *(iface->get_location_on_screen) (component, x, y));
}

void
gaccessible_component_request_focus (GaccessibleComponent    *component)
{
  GaccessibleComponentInterface *iface = NULL;
  g_return_value_if_fail( (component != null), false);
  g_return_value_if_fail( G_IS_GACCESSIBLE_COMPONENT (component), false);
  g_return_value_if_fail( (iface = GACCESSIBLE_COMPONENT_GET_INTERFACE (component)), false );

  return ( *(iface->request_focus) (component));
}

gboolean
gaccessible_component_set_bounds             (GaccessibleComponent    *component,
                                              gint                     x,
                                              gint                     y,
                                              gint                     width,
                                              gint                     length)
{
  GaccessibleComponentInterface *iface = NULL;
  g_return_value_if_fail( (component != null), false);
  g_return_value_if_fail( G_IS_GACCESSIBLE_COMPONENT (component), false);
  g_return_value_if_fail( (iface = GACCESSIBLE_COMPONENT_GET_INTERFACE (component)), false );

  return ( *(iface->set_bounds) (component, x, y, width, length));
}

gboolean
gaccessible_component_set_cursor_type        (GaccessibleComponent    *component,
                                              GaccessibleCursorType    cursortype)
{
  GaccessibleComponentInterface *iface = NULL;
  g_return_value_if_fail( (component != null), false);
  g_return_value_if_fail( G_IS_GACCESSIBLE_COMPONENT (component), false);
  g_return_value_if_fail( (iface = GACCESSIBLE_COMPONENT_GET_INTERFACE (component)), false );

  return ( *(iface->set_cursor_type) (component, cursortype));
}

gboolean
gaccessible_component_set_enabled            (GaccessibleComponent    *component,
                                              gboolean                 b)
{
  GaccessibleComponentInterface *iface = NULL;
  g_return_value_if_fail( (component != null), false);
  g_return_value_if_fail( G_IS_GACCESSIBLE_COMPONENT (component), false);
  g_return_value_if_fail( (iface = GACCESSIBLE_COMPONENT_GET_INTERFACE (component)), false );

  return ( *(iface->set_enabled) (component, b));
}

gboolean
gaccessible_component_set_location           (GaccessibleComponent    *component,
                                              gint                     x,
                                              gint                     y)
{
  GaccessibleComponentInterface *iface = NULL;
  g_return_value_if_fail( (component != null), false);
  g_return_value_if_fail( G_IS_GACCESSIBLE_COMPONENT (component), false);
  g_return_value_if_fail( (iface = GACCESSIBLE_COMPONENT_GET_INTERFACE (component)), false );

  return ( *(iface->set_location) (component, x, y));
}

gboolean
gaccessible_component_set_visible            (GaccessibleComponent    *component,
                                              gboolean                 b)
{
  GaccessibleComponentInterface *iface = NULL;
  g_return_value_if_fail( (component != null), false);
  g_return_value_if_fail( G_IS_GACCESSIBLE_COMPONENT (component), false);
  g_return_value_if_fail( (iface = GACCESSIBLE_COMPONENT_GET_INTERFACE (component)), false );

  return ( *(iface->set_visible) (component, b));
}




