/* GTK - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*
 * Modified by the GTK+ Team and others 1997-2001.  See the AUTHORS
 * file for a list of people on the GTK+ Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
 */

#ifndef __G_ACCESSIBLE_COMPONENT_H__
#define __G_ACCESSIBLE_COMPONENT_H__

#include <gdk/gdk.h>
#include <gtk/gtkdata.h>

#include <gtk/a11y/gaccessible.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */


#define TYPE_GACCESSIBLE_COMPONENT            (gaccessible_component_get_type ())
#define IS_GACCESSIBLE_COMPONENT(obj)         G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GACCESSIBLE_COMPONENT)
#define GACCESSIBLE_COMPONENT(obj)            G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GACCESSIBLE_COMPONENT, gaccessible_component)
#define GACCESSIBLE_COMPONENT_GET_INTERFACE(obj)  (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_GACCESSIBLE_COMPONENT, GaccessibleComponentInterface))

#ifndef _TYPEDEF_GACCESSIBLE_COMPONENT_
#define  _TYPEDEF_GACCESSIBLE_COMPONENT_
typedef struct _GaccessibleComponent GaccessibleComponent;
#endif

typedef gint  GaccessibleCursorType;

struct _GaccessibleComponentInterface
{
  GTypeInterface parent;

  gboolean       (* contains)           (GaccessibleComponent   *component,
                                         gint                   x,
                                         gint                   y);

  Gaccessible*   (* get_accessible_at)  (GaccessibleComponent   *component,
                                         gint                   x,
                                         gint                   y);

  /*
   * This return from this function gives the dimensions which would be
   * returned by get_size().
   */

  void                     (* get_bounds)       (GaccessibleComponent   *component,
                                                 gint                   *x,
                                                 gint                   *y,
                                                 gint                   *width,
                                                 gint                   *height);

  GaccessibleCursorType    (* get_cursor)       (GaccessibleComponent   *component);

  void                     (* get_location)     (GaccessibleComponent   *component,
                                                 gint                   *x,
                                                 gint                   *y);

  void                     (* get_location_on_screen)   (GaccessibleComponent   *component,
                                                         gint                   *x,
                                                         gint                   *y);

  gboolean                 (* request_focus)    (GaccessibleComponent   *component);

  gboolean                 (* set_cursor_type)  (GaccessibleComponent   *component,
                                                 GaccessibleCursorType  cursortype);

  gboolean                 (* set_enabled)      (GaccessibleComponent   *component);

  gboolean                 (* set_location)     (GaccessibleComponent   *component,
                                                 gint                   x,
                                                 gint                   y);

  gboolean                 (* set_visible)      (GaccessibleComponent   *component,
                                                 gboolean               b);

};
GType gaccessible_component_get_type ();

/* convenience functions */

gboolean              gaccessible_component_add_focus_listener     (GaccessibleComponent                       *component,
                                                                    gchar           *listener);
gboolean              gaccessible_component_contains               (GaccessibleComponent                       *component,
                                                                    GdkPoint                                    point);
Gaccessible*          gaccessible_component_get_accessible_at      (GaccessibleComponent                       *component,
                                                                    GdkPoint                                    point);
void                  gaccessible_component_get_bounds             (GaccessibleComponent                       *component,
                                                                    gint                                       *x,
                                                                    gint                                       *y,
                                                                    gint                                       *width,
                                                                    gint                                       *length);
GaccessibleCursorType gaccessible_component_get_cursor_type        (GaccessibleComponent                       *component);
void                  gaccessible_component_get_location           (GaccessibleComponent                       *component,
                                                                    gint                                       *x,
                                                                    gint                                       *y);
void                  gaccessible_component_get_location_on_screen (GaccessibleComponent                       *component,
                                                                    gint                                       *x,
                                                                    gint                                       *y);
void                  gaccessible_component_request_focus          (GaccessibleComponent                       *component);
gboolean              gaccessible_component_set_bounds             (GaccessibleComponent                       *component,
                                                                    gint                                        x,
                                                                    gint                                        y,
                                                                    gint                                        width,
                                                                    gint                                        length);
gboolean              gaccessible_component_set_cursor_type        (GaccessibleComponent                       *component,
                                                                    GaccessibleCursorType                       cursortype);
gboolean              gaccessible_component_set_enabled            (GaccessibleComponent                       *component,
                                                                    gboolean                                    b);
gboolean              gaccessible_component_set_location           (GaccessibleComponent                       *component,
                                                                    gint                                        x,
                                                                    gint                                        y);
gboolean              gaccessible_component_set_visible            (GaccessibleComponent                       *component,
                                                                    gboolean                                    b);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __G_ACCESSIBLE_COMPONENT_H__ */
