/* GTK - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*
 * Modified by the GTK+ Team and others 1997-2001.  See the AUTHORS
 * file for a list of people on the GTK+ Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
 */

#ifndef __G_ACCESSIBLE_EDITABLE_TEXT_H__
#define __G_ACCESSIBLE_EDITABLE_TEXT_H__

#include <gtk/a11y/gaccessible.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/*
 * GaccessibleEditableText is used to support access in an "accessibility" context
 * to editing features of editable text widgets.
 */


#define TYPE_GACCESSIBLE_EDITABLE_TEXT            (gaccessible_editable_text_get_type ())
#define IS_GACCESSIBLE_EDITABLE_TEXT(obj)         G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GACCESSIBLE_EDITABLE_TEXT)
#define GACCESSIBLE_EDITABLE_TEXT(obj)            G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GACCESSIBLE_EDITABLE_TEXT, GaccessibleEditableText)
#define GACCESSIBLE_EDITABLE_TEXT_GET_INTERFACE(obj)  (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_GACCESSIBLE_EDITABLE_TEXT, GaccessibleEditableTextInterface))

#ifndef _TYPEDEF_GACCESSIBLE_EDITABLE_TEXT_
#define _TYPEDEF_GACCESSIBLE_EDITABLE_TEXT_
typedef struct _GaccessibleEditableText GaccessibleEditableText;
#endif

/*
 * This needs to be defined
 */
typedef struct GaccessibleAttributeSet GaccessibleAttributeSet;

struct _GaccessibleEditableTextInterface
{
  GTypeInterface parent_interface;

  void   (* select_text)          (gint startIndex,
                                   gint endIndex);
  void   (* set_attributes)       (gint startIndex,
                                   gint endIndex,
                                   GaccessibleAttributeSet *attributes);
  void   (* set_text_contents)    (gchar *string);
  void   (* insert_text_at_index) (gint index,
                                   gchar *string);
  void   (* cut)                  (gint startIndex,
                                   gint endIndex);
  void   (* delete)               (gint startIndex,
                                   gint endIndex);
  void   (* paste)                (gint index);
};
GType gaccessible_editable_text_get_type (void);

void gaccessible_editable_text_select_text          (gint                     startIndex,
                                                     gint                     endIndex);
void gaccessible_editable_text_set_attributes       (gint                     startIndex,
                                                     gint                     endIndex,
                                                     GaccessibleAttributeSet *attributes);
void gaccessible_editable_text_set_text_contents    (gchar                   *string);
void gaccessible_editable_text_insert_text_at_index (gint                     index,
                                                     gchar                   *string);
void gaccessible_editable_text_cut                  (gint                     startIndex,
                                                     gint                     endIndex);
void gaccessible_editable_text_delete               (gint                     startIndex,
                                                     gint                     endIndex);
void gaccessible_editable_text_paste                (gint                     index);

#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __G_ACCESSIBLE_EDITABLE_TEXT_H__ */



