/* GTK - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*
 * Modified by the GTK+ Team and others 1997-2001.  See the AUTHORS
 * file for a list of people on the GTK+ Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
 */

#ifndef __G_ACCESSIBLE_HYPERTEXT_H__
#define __G_ACCESSIBLE_HYPERTEXT_H__

#include <gtk/a11y/gaccessible.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/*
 * AccessibleHypertext is used to support accessibility for widgets which
 * support the display of HTML. I do not think that there is a GTK+ widget
 * for this but I assume that there will be a custom widget so we define
 * the interface.
 */


#define TYPE_GACCESSIBLE_HYPERTEXT            (gaccessible_hypertext_get_type ())
#define IS_GACCESSIBLE_HYPERTEXT(obj)         G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GACCESSIBLE_HYPERTEXT)
#define GACCESSIBLE_HYPERTEXT(obj)            G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GACCESSIBLE_HYPERTEXT, GaccessibleHypertext)
#define GACCESSIBLE_HYPERTEXT_GET_INTERFACE(obj)  (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_GACCESSIBLE_HYPERTEXT, GaccessibleHypertextInterface))

#ifndef _TYPEDEF_ACCESSIBLE_HYPERTEXT_
#define _TYPEDEF_ACCESSIBLE_HYPERTEXT_
typedef struct _GaccessibleHypertext GaccessibleHypertext;
#endif

typedef struct _GaccessibleHyperLink  GaccessibleHyperLink;

struct _GaccessibleHypertextInterface
{
  GTypeInterface parent;

  /* TODO Define GaccessibleHyperLink */
  GaccessibleHyperLink (* get_link)                 (GaccessibleHypertext       *hypertext,
                                                     gint                       linkIndex);

  gint                 (* get_link_count)           (GaccessibleHypertext       *hypertext);

  gint                 (* get_link_index)           (GaccessibleHypertext       *hypertext,
                                                     gint                       char_index);

};
GType gaccessible_hypertext_get_type (void);

GaccessibleHyperLink gaccessible_hypertext_get_link       (GaccessibleHypertext *hypertext,
                                                           gint                  linkIndex);
gint                 gaccessible_hypertext_get_link_count (GaccessibleHypertext *hypertext);
gint                 gaccessible_hypertext_get_link_index (GaccessibleHypertext *hypertext,
                                                           gint                  char_index);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __G_ACCESSIBLE_HYPERTEXT_H__ */



