/* GTK - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*
 * Modified by the GTK+ Team and others 1997-2001.  See the AUTHORS
 * file for a list of people on the GTK+ Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
 */

#ifndef __G_ACCESSIBLE_ICON_H__
#define __G_ACCESSIBLE_ICON_H__

#include <gtk/a11y/gaccessible.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/*
 * GaccessibleIcon should be supported by any widget which has an associated
 * icon.
 */

#define TYPE_GACCESSIBLE_ICON            (gaccessible_icon_get_type ())
#define IS_GACCESSIBLE_ICON(obj)         G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GACCESSIBLE_ICON)
#define GACCESSIBLE_ICON(obj)            G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GACCESSIBLE_ICON, GaccessibleIcon)
#define GACCESSIBLE_ICON_GET_INTERFACE(obj)  (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_GACCESSIBLE_ICON, GaccessibleIconInterface))

#ifndef _TYPEDEF_GACCESSIBLE_ICON_
#define _TYPEDEF_GACCESSIBLE_ICON_
typedef struct _GaccessibleIcon GaccessibleIcon;
#endif

struct _GaccessibleIconInterface
{
  GTypeInterface parent;

  gchar* ( *get_icon_description) (GaccessibleIcon              *icon);

  gint   ( *get_icon_height)      (GaccessibleIcon              *icon);

  gint   ( *get_icon_width)       (GaccessibleIcon              *icon);

  void   ( *set_icon_description) (GaccessibleIcon              *icon,
                                   gchar                        *description);

};
GType  gaccessible_icon_get_type             (void);

gchar* gaccessible_icon_get_icon_description (GaccessibleIcon   *icon);

gint   gaccessible_icon_get_icon_height      (GaccessibleIcon           *icon);

gint   gaccessible_icon_get_icon_width       (GaccessibleIcon           *icon);

void   gaccessible_icon_set_icon_description (GaccessibleIcon           *icon,
                                              gchar                     *description);


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __G_ACCESSIBLE_ICON_H__ */
