/* GTK - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*
 * Modified by the GTK+ Team and others 1997-2001.  See the AUTHORS
 * file for a list of people on the GTK+ Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
 */

#ifndef __G_ACCESSIBLE_SELECTION_H__
#define __G_ACCESSIBLE_SELECTION_H__

#include <gtk/a11y/gaccessible.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/*
 * AccessibleSelection should be supported by any widget which has children
 * which can be selected.
 */


#define TYPE_GACCESSIBLE_SELECTION                (gaccessible_selection_get_type ())
#define G_IS_GACCESSIBLE_SELECTION(obj)           G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GACCESSIBLE_SELECTION)
#define GACCESSIBLE_SELECTION(obj)                G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GACCESSIBLE_SELECTION, GaccessibleSelection)
#define GACCESSIBLE_SELECTION_GET_INTERFACE(obj)  (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_GACCESSIBLE_SELECTION, GaccessibleSelectionInterface))

#ifndef _TYPEDEF_GACCESSIBLE_SELECTION_
#define _TYPEDEF_GACCESSIBLE_SELECTION_
typedef struct _GaccessibleSelection GaccessibleSelection;
#endif

struct _GaccessibleSelectionInterface
{
  GTypeInterface parent;

  void         (* add_selection)        (GaccessibleSelection   *selection,
                                         gint                   i);

  void         (* clear_selection)      (GaccessibleSelection   *selection);

  Gaccessible* (* get_selection)        (GaccessibleSelection   *selection,
                                         gint                   i);

  gint         (* get_selection_count)  (GaccessibleSelection   *selection);

  gboolean     (* is_child_selected)    (GaccessibleSelection   *selection,
                                         gint                   i);

  void         (* remove_selection)     (GaccessibleSelection   *selection,
                                         gint                   i);

  void         (* select_all_selection) (GaccessibleSelection   *selection);

};
GType gaccessible_selection_get_type ();


/* TODO: define convenience functions that map to  above virtual funcs */

#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __G_ACCESSIBLE_SELECTION_H__ */
