/* GTK - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*
 * Modified by the GTK+ Team and others 1997-2001.  See the AUTHORS
 * file for a list of people on the GTK+ Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
 */

#ifndef __G_ACCESSIBLE_TABLE_H__
#define __G_ACCESSIBLE_TABLE_H__

#include <gtk/a11y/gaccessible.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/*
 * AccessibleTable describes a user-interface component that presents data in
 * two-dimensional table format.
 */


#define TYPE_GACCESSIBLE_TABLE            (gaccessible_table_get_type ())
#define IS_GACCESSIBLE_TABLE(obj)         G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GACCESSIBLE_TABLE)
#define GACCESSIBLE_TABLE(obj)            G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GACCESSIBLE_TABLE, GaccessibleTable)
#define GACCESSIBLE_TABLE_GET_INTERFACE(obj)  (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_GACCESSIBLE_TABLE, GaccessibleTableInterface))

#ifndef _TYPEDEF_GACCESSIBLE_TABLE_
#define _TYPEDEF_GACCESSIBLE_TABLE_
typedef struct _GaccessibleTable GaccessibleTable;
#endif

struct _GaccessibleTableInterface
{
  GTypeInterface parent;

  Gaccessible*      (* ref_at)                   (GaccessibleTable      *table,
                                                  gint                  r,
                                                  gint                  c);
  gint              (* get_index_at)             (GaccessibleTable      *table,
                                                  gint                  r,
                                                  gint                  c);
  gint              (* get_row_at_index)         (GaccessibleTable      *table,
                                                  gint                  index);
  gint              (* get_column_at_index)      (GaccessibleTable      *table,
                                                  gint                  index);
  gchar*            (* get_caption)              (GaccessibleTable      *table);
  gint              (* get_column_count)         (GaccessibleTable      *table);
  gchar*            (* get_column_description)   (GaccessibleTable      *table,
                                                  gint                  c);
  gint              (* get_column_extent_at)     (GaccessibleTable      *table,
                                                  gint                  r,
                                                  gint                  c);
  GaccessibleTable* (* get_column_header)        (GaccessibleTable      *table);
  gint              (* get_row_count)            (GaccessibleTable      *table);
  gchar*            (* get_row_description)      (GaccessibleTable      *table,
                                                  gint                  r);
  gint              (* get_row_extent_at)        (GaccessibleTable      *table,
                                                  gint                  r,
                                                  gint                  c);
  GaccessibleTable* (* get_row_header)           (GaccessibleTable      *table);
  Gaccessible*      (* get_summary)              (GaccessibleTable      *table);
  gint*             (* get_selected_columns)     (GaccessibleTable      *table);
  gint*             (* get_selected_rows)        (GaccessibleTable      *table);
  gboolean          (* is_column_selected)       (GaccessibleTable      *table,
                                                  gint                  c);
  gboolean          (* is_row_selected)          (GaccessibleTable      *table,
                                                  gint                  r);
  gboolean          (* is_selected)              (GaccessibleTable      *table,
                                                  gint                  r,
                                                  gint                  c);
  void              (* set_caption)              (GaccessibleTable      *table,
                                                  Gaccessible           *a);
  void              (* set_column_description)   (GaccessibleTable      *table,
                                                  gint                  c,
                                                  Gaccessible           *a);
  void              (* set_column_header)        (GaccessibleTable      *table,
                                                  gint                  c,
                                                  GaccessibleTable      *t);
  void              (* set_row_description)      (GaccessibleTable      *table,
                                                  gint                  r,
                                                  Gaccessible           *a);
  void              (* set_row_header)           (GaccessibleTable      *table,
                                                  gint                  r,
                                                  GaccessibleTable      *t);
  void              (* set_summary)              (GaccessibleTable      *table,
                                                  Gaccessible           *a);
};

GType gaccessible_table_get_type ();
Gaccessible*      accessible_table_ref_at                 (GaccessibleTable         *table,
                                                           gint                      r,
                                                           gint                      c);
gint              accessible_table_get_index_at           (GaccessibleTable         *table,
                                                           gint                      r,
                                                           gint                      c);
gint              accessible_table_get_row_at_index       (GaccessibleTable         *table,
                                                           gint                      index);
gint              accessible_table_get_column_at_index    (GaccessibleTable         *table,
                                                           gint                      index);
gchar*            accessible_table_get_caption            (GaccessibleTable         *table);
gint              accessible_table_get_column_count       (GaccessibleTable         *table);
gchar*            accessible_table_get_column_description (GaccessibleTable         *table,
                                                           gint                      c);
gint              accessible_table_get_column_extent_at   (GaccessibleTable         *table,
                                                           gint                      r,
                                                           gint                      c);
GaccessibleTable* accessible_table_get_column_header      (GaccessibleTable         *table);
gint              accessible_table_get_row_count          (GaccessibleTable         *table);
gchar*            accessible_table_get_row_description    (GaccessibleTable         *table,
                                                           gint                      r);
gint              accessible_table_get_row_extent_at      (GaccessibleTable         *table,
                                                           gint                      r,
                                                           gint                      c);
GaccessibleTable* accessible_table_get_row_header         (GaccessibleTable         *table);
Gaccessible*      accessible_table_get_summary            (GaccessibleTable         *table);
gint*             accessible_table_get_selected_columns   (GaccessibleTable         *table);
gint*             accessible_table_get_selected_rows      (GaccessibleTable         *table);
gboolean          accessible_table_is_column_selected     (GaccessibleTable         *table,
                                                           gint                      c);
gboolean          accessible_table_is_row_selected        (GaccessibleTable         *table,
                                                           gint                      r);
gboolean          accessible_table_is_selected            (GaccessibleTable         *table,
                                                           gint                      r,
                                                           gint                      c);
void              accessible_table_set_caption            (GaccessibleTable         *table,
                                                           gchar                    *s);
void              accessible_table_set_column_description (GaccessibleTable         *table,
                                                           gint                      c,
                                                           Gaccessible              *s);
void              accessible_table_set_column_header      (GaccessibleTable         *table,
                                                           gint                      c,
                                                           Gaccessible              *a);
void              accessible_table_set_row_description    (GaccessibleTable         *table,
                                                           gint                      r,
                                                           gchar                    *s);
void              accessible_table_set_row_header         (GaccessibleTable         *table,
                                                           gint                      r,
                                                           GaccessibleTable         *t);
void              accessible_table_set_summary            (GaccessibleTable         *table,
                                                           Gaccessible              *a);

#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __G_ACCESSIBLE_TABLE_H__ */

