/* GTK - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*
 * Modified by the GTK+ Team and others 1997-2001.  See the AUTHORS
 * file for a list of people on the GTK+ Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
 */

#ifndef __G_ACCESSIBLE_TEXT_H__
#define __G_ACCESSIBLE_TEXT_H__

#include <gtk/a11y/gaccessible.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define TYPE_GACCESSIBLE_TEXT            (gaccessible_text_get_type ())
#define IS_GACCESSIBLE_TEXT(obj)         G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GACCESSIBLE_TEXT)
#define GACCESSIBLE_TEXT(obj)            G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GACCESSIBLE_TEXT, GaccessibleText)
#define GACCESSIBLE_TEXT_GET_INTERFACE(obj)  (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_GACCESSIBLE_TEXT, GaccessibleTextInterface))

#ifndef _TYPEDEF_GACCESSIBLE_TEXT_
#define _TYPEDEF_GACCESSIBLE_TEXT_
typedef struct _GaccessibleText GaccessibleText;
#endif

typedef struct _GaccessibleTextDelimiter GaccessibleTextDelimiter;

struct _GaccessibleTextInterface
{
  GTypeInterface parent;

  gchar* (* get_character_after_index)          (GaccessibleText *text,
                                                 gint index);
  gchar* (* get_text_after_index)               (GaccessibleText *text,
                                                 gint index,
                                                 GaccessibleTextDelimiter *delims);
  gchar* (* get_character_at_index)             (GaccessibleText *text,
                                                 gint index);
  gchar* (* get_text_at_index)                  (GaccessibleText *text,
                                                 gint index,
                                                 GaccessibleTextDelimiter *delims);
  gchar* (* get_character_before_index)          (GaccessibleText *text,
                                                 gint index);
  gchar* (* get_text_before_index)              (GaccessibleText *text,
                                                 gint index,
                                                 GaccessibleTextDelimiter *delims);

  gchar* (* get_text_range)                      (GaccessibleText *text,
                                                  gint startIndex,
                                                  gint endIndex);
  gint   (* get_caret_index)                     (GaccessibleText *text);
  void   (* get_row_col_at_index)                (GaccessibleText *text,
                                                  gint index,
                                                  gint *row,
                                                  gint *col);

  /* TODO: Not sure what kind of structure we need
   * in which to return text attribute set.
   * (must replace void* with something useful!)
   */

  void*  (* get_character_attributes)            (GaccessibleText *text,
                                                  gint index);

  void   (* get_character_bounds)                (GaccessibleText *text,
                                                  gint index,
                                                  gint *x,
                                                  gint *y,
                                                  gint *length,
                                                  gint *width);

  gint   (* get_character_count)                 (GaccessibleText *text);

  gint   (* get_index_at_point)                  (GaccessibleText *text,
                                                  gint x,
                                                  gint y);

  gchar* (* get_selected_text)                   (GaccessibleText *text);
  /* why not use accessible_Selection() ? */

  gint   (* get_selection_end)                   (GaccessibleText *text);

  gint   (* get_selection_start)                 (GaccessibleText *text);

};
GType            gaccessible_text_get_type (void);


/*
 * Additional GObject properties exported by GaccessibleText:
 *    "accessible_text" (accessible text has changed)
 *    "accessible_caret" (accessible text cursor position changed:
 *                         editable text only)
 */

/* TODO: more convenience function definitions that wrap the func pointers above. */

gchar* gaccessible_text_get_text_range                    (GaccessibleText      *text,
                                                           gint                 startIndex,
                                                           gint                 endIndex);
gchar* gaccessible_text_get_sentence_after_index          (GaccessibleText      *text,
                                                           gint                  index);
gchar* gaccessible_text_get_word_after_index              (GaccessibleText      *text,
                                                           gint                  index);
gchar* gaccessible_text_get_character_at_index            (GaccessibleText      *text,
                                                           gint                  index);
gchar* gaccessible_text_get_sentence_at_index             (GaccessibleText      *text,
                                                           gint                  index);
gchar* gaccessible_text_get_word_at_index                 (GaccessibleText      *text,
                                                           gint                  index);
gchar* gaccessible_text_get_character_before_index        (GaccessibleText      *text,
                                                           gint                  index);
gchar* gaccessible_text_get_sentence_before_index         (GaccessibleText      *text,
                                                           gint                  index);
gchar* gaccessible_text_get_word_before_index             (GaccessibleText      *text,
                                                           gint                  index);


/* NOTE: some of the above implementation may fail for non-latin character sets - use methods below */
gchar* gaccessible_text_get_character_string_after_index  (GaccessibleText      *text,
                                                           gint                  index,
                                                           GaccessibleTextDelimiter *delims);
gchar* gaccessible_text_get_character_string_at_index     (GaccessibleText      *text,
                                                           gint                  index,
                                                           GaccessibleTextDelimiter *delims);
gchar* gaccessible_text_get_character_string_before_index (GaccessibleText      *text,
                                                           gint                  index,
                                                           GaccessibleTextDelimiter *delims);



#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __G_ACCESSIBLE_TEXT_H__ */
