/* GTK - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*
 * Modified by the GTK+ Team and others 1997-2001.  See the AUTHORS
 * file for a list of people on the GTK+ Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
 */

#ifndef __G_ACCESSIBLE_VALUE_H__
#define __G_ACCESSIBLE_VALUE_H__

#include <gtk/a11y/gaccessible.h>

#define TYPE_GACCESSIBLE_VALUE            (gaccessible_value_get_type ())
#define IS_GACCESSIBLE_VALUE(obj)         G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GACCESSIBLE_VALUE)
#define GACCESSIBLE_VALUE(obj)            G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GACCESSIBLE_VALUE, GaccessibleValue)
#define GACCESSIBLE_VALUE_GET_INTERFACE(obj)  (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_GACCESSIBLE_VALUE, GaccessibleValueInterface))

#ifndef _TYPEDEF_GACCESSIBLE_VALUE_
#define _TYPEDEF_GACCESSIBLE_VALUE__
typedef struct _GaccessibleValue GaccessibleValue;
#endif

struct _GaccessibleValueInterface
{
  GTypeInterface parent;

  gdouble  (* get_current_value) (GaccessibleValue *value);

  gdouble  (* get_maximum_value) (GaccessibleValue *value);

  gdouble  (* get_minimum_value) (GaccessibleValue *value);

  gboolean (* set_current_value) (GaccessibleValue *value,
                                  gdouble dval);

};

GType            gaccessible_value_get_type (void);

gdouble  gaccessible_value_get_current_value (GaccessibleValue *value);

gdouble  gaccessible_value_get_maximum_value (GaccessibleValue *value);

gdouble  gaccessible_value_get_minimum_value (GaccessibleValue *value);

gboolean gaccessible_value_set_current_value (GaccessibleValue *value,
                                              gdouble dval);

/*
 * Additional GObject properties exported by GaccessibleValue:
 *    "accessible_value"
 *       (the accessible value has changed)
 */


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif /* __G_ACCESSIBLE_VALUE_H__ */
