/* GTK - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*
 * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
 * file for a list of people on the GTK+ Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
 */

#include <stdarg.h>
#include <stdio.h>
#include <string.h>

#include "gtk/gtkwidget.h"
#include "gtkaccessiblefactory.h"

static void gtk_accessible_factory_class_init   (GtkAccessibleFactoryClass        *klass);

static gpointer    parent_class = NULL;

GtkType
gtk_accessible_factory_get_type ()
{
  static GType type = 0;

  if (!type) {
    GTypeInfo tinfo =
    {
      sizeof (GtkAccessibleFactoryClass),
      (GBaseInitFunc) NULL, /* base init */
      (GBaseFinalizeFunc) NULL, /* base finalize */
      (GClassInitFunc) gtk_accessible_factory_class_init, /* class init */
      (GClassFinalizeFunc) NULL, /* class finalize */
      NULL, /* class data */
      sizeof (GtkAccessibleFactory), /* instance size */
      0, /* nb preallocs */
      (GInstanceInitFunc) NULL, /* instance init */
      NULL /* value table */
    };

    type = g_type_register_static (G_TYPE_OBJECT, "GtkAccessibleFactory", &tinfo, 0);
  }
  return type;
}

static void gtk_accessible_factory_class_init (GtkAccessibleFactoryClass *klass)
{
  GObjectClass *gobject_class = G_OBJECT_CLASS (klass);

  parent_class = g_type_class_ref (G_TYPE_OBJECT);

}


GtkAccessible* gtk_accessible_factory_create_accessible (
             GtkAccessibleFactory *factory,
             GtkWidget            *widget)
{
  GtkAccessibleFactoryClass *klass;
  GtkAccessible *accessible = NULL;

  g_return_val_if_fail (factory != NULL, NULL);
  g_return_val_if_fail (GTK_IS_ACCESSIBLEFACTORY (factory), NULL);
  g_return_val_if_fail (widget != NULL, NULL);
  g_return_val_if_fail (GTK_IS_WIDGET (widget), NULL);

  klass = GTK_ACCESSIBLEFACTORY_GET_CLASS (factory);

  if (klass->create_accessible)
  {
      accessible = klass->create_accessible (widget);
  }
  return accessible;
} 

